;------------------------------------------------------------
;------------------------------------------------------------
;------------------------------------------------------------
;+
;
; gives yyyymmdd date equivalent of a julian day
;
; @categories calendar
;
; @param jday {in}{required} julian day
;
; @returns date in yyyymmdd format
;
; @examples 
;
;    IDL> print, jul2date(julday(12,23,1999))
;        19991223
;
; @history Sebastien Masson (smasson\@lodyc.jussieu.fr)
;                       June 2005
;-
;------------------------------------------------------------
;------------------------------------------------------------
;------------------------------------------------------------
function jul2date, jday

  caldat, jday, month, day, year

  res = (10000L*year + 100L*month + day)*(year GE 0) $
        +( 10000L*year - 100L*month - day)*(year LT 0)

  return, long(res)
end
